@@ -1,6 +1,5 @@
 import datetime as dt
-from collections.abc import Iterable, Iterator
-from typing import NamedTuple, Union
+from typing import Iterable, Iterator, NamedTuple, Union
 
 import attr
 
@@ -23,7 +22,7 @@ class Coordinates(NamedTuple):
 
 
 @attr.s
-class PrayerTimes(Iterable):
+class PrayerTimes(Iterable[Prayer]):
     date = attr.ib(type=dt.date)
     fajr = attr.ib(type=Prayer)
     dhuhr = attr.ib(type=Prayer)
@@ -31,16 +30,16 @@ class PrayerTimes(Iterable):
     maghrib = attr.ib(type=Prayer)
     isha = attr.ib(type=Prayer)
 
-    def __iter__(self):
+    def __iter__(self):  # type: () -> PrayerIterator
         return PrayerIterator(self)
 
 
-class PrayerIterator(Iterator):
-    def __init__(self, pt: PrayerTimes):
+class PrayerIterator(Iterator[Prayer]):
+    def __init__(self, pt: PrayerTimes) -> None:
         self.index = 0
         self.pt = pt
 
-    def __iter__(self):
+    def __iter__(self):  # type: () -> PrayerIterator
         return self
 
     def __next__(self) -> Prayer:
